Knowledge Graph Embedding (KGE) Models
======================================
.. automodule:: pykeen.kge_models
   :members:

.. warning::

    * Embedding dimension: Must be a positive integer (e.g. 50)
    * Margin loss: Is a float value (e.g. 1.5, -0.8)
    * Scoring function norm:
